import { type IViewContainerDescriptor, type IViewContainersRegistry, type IViewDescriptor, type IViewsRegistry, type ViewContainer, ViewContainerLocation } from "@codingame/monaco-vscode-api/vscode/vs/workbench/common/views";
import type { BrandedService, ServicesAccessor } from "@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/instantiation";
import { type IDisposable } from "@codingame/monaco-vscode-api/vscode/vs/base/common/lifecycle";
import { Dimension } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/dom";
import { ViewPaneContainer } from "@codingame/monaco-vscode-91789cdf-e3cb-5a04-aaeb-6f7df7d3d231-common/vscode/vs/workbench/browser/parts/views/viewPaneContainer";
import { URI } from "@codingame/monaco-vscode-api/vscode/vs/base/common/uri";
import { Codicon } from "@codingame/monaco-vscode-api/vscode/vs/base/common/codicons";
import { type EditorInputFactoryObject, type RegisteredEditorInfo, type RegisteredEditorOptions, RegisteredEditorPriority } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/editor/common/editorResolverService";
import { EditorInput, type IEditorCloseHandler } from "@codingame/monaco-vscode-api/vscode/vs/workbench/common/editor/editorInput";
import { EditorInputCapabilities, type IEditorOpenContext, type IEditorSerializer, Verbosity } from "@codingame/monaco-vscode-api/vscode/vs/workbench/common/editor";
import type { IEditorOptions, IResourceEditorInput } from "@codingame/monaco-vscode-api/vscode/vs/platform/editor/common/editor";
import { EditorPane } from "@codingame/monaco-vscode-d0fb86d3-2a47-594e-955b-9a24631a7124-common/vscode/vs/workbench/browser/parts/editor/editorPane";
import { CancellationToken } from "@codingame/monaco-vscode-api/vscode/vs/base/common/cancellation";
import { DomScrollableElement } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/ui/scrollbar/scrollableElement";
import { ConfirmResult } from "@codingame/monaco-vscode-d4a98668-f793-5361-a9cf-1e6ae6d62ce3-common/vscode/vs/platform/dialogs/common/dialogs";
import { AbstractResourceEditorInput } from "@codingame/monaco-vscode-api/vscode/vs/workbench/common/editor/resourceEditorInput";
import { AbstractTextResourceEditorInput } from "@codingame/monaco-vscode-ce8c4b18-4e75-55dd-9656-517347af9de7-common/vscode/vs/workbench/common/editor/textResourceEditorInput";
import { Parts, Position } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/layout/browser/layoutService";
import { Event } from "@codingame/monaco-vscode-api/vscode/vs/base/common/event";
import { type IView, SplitView } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/ui/splitview/splitview";
import { type IEditorGroup } from "@codingame/monaco-vscode-api/services";
type Label = string | {
    short: string;
    medium: string;
    long: string;
};
declare abstract class InjectedEditorPane extends EditorPane {
    constructor(id: string, group: IEditorGroup);
}
declare abstract class SimpleEditorPane extends InjectedEditorPane {
    protected container: HTMLElement;
    protected wrapper: HTMLElement;
    protected scrollbar: DomScrollableElement | undefined;
    private inputDisposable;
    protected createEditor(parent: HTMLElement): void;
    setInput(input: EditorInput, editorOptions: IEditorOptions | undefined, context: IEditorOpenContext, token: CancellationToken): Promise<void>;
    layout(dimension: Dimension): void;
    focus(): void;
    clearInput(): void;
    abstract initialize(): HTMLElement;
    abstract renderInput?(input: EditorInput, options: IEditorOptions | undefined, context: IEditorOpenContext, token: CancellationToken): Promise<IDisposable>;
}
declare abstract class SimpleEditorInput extends EditorInput {
    closeHandler?: IEditorCloseHandler | undefined;
    private dirty;
    private _capabilities;
    private name;
    private title;
    private description;
    resource: URI | undefined;
    constructor(resource?: URI, closeHandler?: IEditorCloseHandler | undefined);
    get capabilities(): EditorInputCapabilities;
    addCapability(capability: EditorInputCapabilities): void;
    removeCapability(capability: EditorInputCapabilities): void;
    get editorId(): string | undefined;
    setName(name: string): void;
    setTitle(title: Label): void;
    setDescription(description: string): void;
    private getLabelValue;
    getName(): string;
    getTitle(verbosity?: Verbosity): string;
    getDescription(verbosity?: Verbosity): string;
    isDirty(): boolean;
    setDirty(dirty: boolean): void;
    toUntyped(): IResourceEditorInput | undefined;
}
declare function registerEditorPane<Services extends BrandedService[]>(typeId: string, name: string, ctor: new (group: IEditorGroup, ...services: Services) => EditorPane, inputCtors: (new (...args: any[]) => EditorInput)[]): IDisposable;
declare function registerEditor(globPattern: string, editorInfo: RegisteredEditorInfo, editorOptions: RegisteredEditorOptions, factory: EditorInputFactoryObject): IDisposable;
declare function registerEditorSerializer<Services extends BrandedService[]>(editorTypeId: string, ctor: {
    new (...Services: Services): IEditorSerializer;
}): IDisposable;
interface CustomViewOption {
    readonly id: string;
    name: string;
    order?: number;
    renderBody(container: HTMLElement, scrollbar: DomScrollableElement): IDisposable;
    location: ViewContainerLocation;
    icon?: string;
    canMoveView?: boolean;
    default?: boolean;
    actions?: {
        id: string;
        title: string;
        tooltip?: string;
        order?: number;
        run?(accessor: ServicesAccessor): Promise<void>;
        icon?: keyof typeof Codicon;
        render?(container: HTMLElement): void;
    }[];
    viewContainer?: ViewContainer;
    canToggleVisibility?: boolean;
    hideByDefault?: boolean;
    collapsed?: boolean;
}
declare const viewContainerRegistry: IViewContainersRegistry;
declare const viewRegistry: IViewsRegistry;
declare function registerCustomView(options: CustomViewOption): IDisposable;
export declare function isPartVisibile(part: Parts): boolean;
export declare function setPartVisibility(part: Exclude<Parts, Parts.STATUSBAR_PART | Parts.TITLEBAR_PART>, visible: boolean): void;
export declare const onDidChangePanelPosition: Event<string>;
export declare function getPanelPosition(): Position;
export declare const onDidChangeSideBarPosition: Event<string>;
export declare function getSideBarPosition(): Position;
export { ViewContainerLocation, registerCustomView, ViewPaneContainer, ConfirmResult, registerEditorPane, RegisteredEditorPriority, InjectedEditorPane as EditorPane, SimpleEditorPane, SimpleEditorInput, AbstractResourceEditorInput, AbstractTextResourceEditorInput, EditorInput, registerEditor, registerEditorSerializer, EditorInputCapabilities, Parts, SplitView, viewRegistry, viewContainerRegistry, DomScrollableElement };
export type { IEditorSerializer, CustomViewOption, IEditorCloseHandler, RegisteredEditorInfo, RegisteredEditorOptions, EditorInputFactoryObject, IView, IViewContainerDescriptor, ViewContainer, IViewDescriptor };
